@@ -39,7 +39,7 @@ class Audio(object):
         return self.record_file
 
     # 这个其实是wav，为了跟之前的接口保持一致。
-    def play_pcm(self, file_name):
+    def play(self, file_name):
         Player.play(file_name, wait=True)
 
     def wav_to_pcm(self, wav_file):
