@@ -26,6 +26,8 @@ import ssl
 from wsgiref.handlers import format_date_time
 from datetime import datetime
 from time import mktime
+import tempfile
+import wave
 # from qcloud_cos import CosConfig
 # from qcloud_cos import CosS3Client
 # from random import choice
@@ -85,29 +87,6 @@ class Ws_Param(object):
 
 class Tts(object):
     def __init__(self):
-        # secret_id = "AKIDqTt43ryimaDbkrOgFZgYBj2EBsKdbcFf"
-        # secret_key = "Qef6IGAyaHqFRaaN1QVTHvOceU8ZvCE4"
-        # region = 'ap-hongkong'
-        # token = None
-        # scheme = 'https'
-        # prefix = "kdxfsdk/license/tts"
-        # bucket = "lmxia-1253647560"
-        #
-        # config = CosConfig(Region=region, SecretId=secret_id, SecretKey=secret_key, Token=token, Scheme=scheme)
-        # client = CosS3Client(config)
-        # response = client.list_objects(Bucket=bucket, Prefix=prefix)
-        # objs = [obj for obj in response['Contents'] if str(obj.get("Size", '0')) != '0']
-        # iat_item = choice(objs)
-        # license_key = iat_item.get("Key", "kdxfsdk/license/tts/lmxia.config")
-        # spec_obj = client.get_object(
-        #     Bucket=bucket,
-        #     Key=license_key,
-        # )
-        # fp = spec_obj['Body'].get_raw_stream().read()
-        # license_obj = json.loads(fp)
-        # self.APPID = license_obj.get("APPID")
-        # self.APIKey = license_obj.get("APIKey")
-        # self.APISecret = license_obj.get("APISecret")
         self.APPID = "5cc5623f"
         self.APIKey = "fd98921894fe1bade5b95f1ae75d49d8"
         self.APISecret = "8f57d4b3dbb3fb4b77098df502be780f"
@@ -115,10 +94,6 @@ class Tts(object):
     def make_speach(self, text):
         # 测试时候在此处正确填写相关信息即可运行
         # 收到websocket连接建立的处理
-        try:
-            os.remove("./speach.pcm")
-        except OSError:
-            pass
         wsParam = Ws_Param(self.APPID, self.APIKey, self.APISecret, text)
         websocket.enableTrace(False)
         wsUrl = wsParam.create_url()
@@ -138,10 +113,14 @@ class Tts(object):
                 ws.close()
 
             thread.start_new_thread(run, ())
+        global gTTSPath, gTTSResult
+        with tempfile.NamedTemporaryFile() as f:
+            gTTSPath = f.name
 
         ws = websocket.WebSocketApp(wsUrl, on_message=on_message, on_error=on_error, on_close=on_close)
         ws.on_open = on_open
         ws.run_forever(sslopt={"cert_reqs": ssl.CERT_NONE})
+        return gTTSResult
 
 
 # 收到websocket消息的处理
@@ -155,7 +134,7 @@ def on_message(ws, message):
             errMsg = json.loads(message)["message"]
             print("sid:%s call error:%s code is:%s" % (sid, errMsg, code))
         else:
-            with open('./speach.pcm', 'ab') as f:
+            with open(gTTSPath, 'ab') as f:
                 f.write(audio)
     except Exception as e:
         print("receive msg,but parse exception:", e)
@@ -168,6 +147,17 @@ def on_error(ws, error):
 
 # 收到websocket关闭的处理
 def on_close(ws):
+    global gTTSResult
+    with open(gTTSPath, 'rb') as pcmfile:
+        pcmdata = pcmfile.read()
+    tmpfile = ''
+    with tempfile.NamedTemporaryFile() as f:
+        tmpfile = f.name
+
+    with wave.open(tmpfile, 'wb') as wavfile:
+        wavfile.setparams((1, 2, 16000, 0, 'NONE', 'NONE'))
+        wavfile.writeframes(pcmdata)
+    gTTSResult = tmpfile
     pass
 
 
